==> manta_manim_theme-0.4.1.tar.gz: manta_manim_theme-0.4.1/manta/color_theme/catppucin/catppuccin_latte.py <==
from manta.color_theme.catppucin.catppuccin_theme_ABC import CatppuccinThemeABC


class CatppuccinLatteTheme(CatppuccinThemeABC):

    # ThemeABC
    background_color: str = "#eff1f5"
    background_color_bright: str = "#ccd0da"

    surface_color: str = "#ccd0da"
    outline_color: str = "#8c8fa1"

    font_color: str = "#4c4f69"
    font_color_secondary: str = "#5c5f77"

    black: str = "#6c6f85"
    black_bright: str = "#6c6f85"

    red: str = "#d20f39"
    red_bright: str = "#d20f39"

    green: str = "#40a02b"
    green_bright: str = "#40a02b"

    yellow: str = "#df8e1d"
    yellow_bright: str = "#df8e1d"

    blue: str = "#1e66f5"
    blue_bright: str = "#1e66f5"

    magenta: str = "#ea76cb"
    magenta_bright: str = "#ea76cb"

    cyan: str = "#179299"
    cyan_bright: str = "#179299"

    white: str = "#acb0be"
    white_bright: str = "#acb0be"

    # CatppuccinThemeABC
    rosewater: str = "#dc8a78"
    flamingo: str = "#dd7878"
    pink: str = "#ea76cb"
    mauve: str = "#8839ef"
    maroon: str = "#e64553"
    peach: str = "#fe640b"
    teal: str = "#179299"
    sky: str = "#04a5e5"
    sapphire: str = "#209fb5"
    lavender: str = "#7287fd"
    text: str = "#4c4f69"
    subtext1: str = "#5c5f77"
    subtext0: str = "#6c6f85"
    overlay2: str = "#7c7f93"
    overlay1: str = "#8c8fa1"
    overlay0: str = "#9ca0b0"
    surface2: str = "#acb0be"
    surface1: str = "#bcc0cc"
    surface0: str = "#ccd0da"
    base: str = "#eff1f5"
    mantle: str = "#e6e9ef"
    crust: str = "#dce0e8"

==> manta_manim_theme-0.6.8.tar.gz: manta_manim_theme-0.6.8/manta/color_theme/catppucin/catppuccin_latte.py <==
from manta.color_theme.catppucin.catppuccin_theme_ABC import CatppuccinThemeABC


class CatppuccinLatteTheme(CatppuccinThemeABC):
    """
    CatppuccinLatteTheme defines colors for the Catppuccin Latte colorscheme as defined in
    https://github.com/catppuccin/catppuccin
    """

    # ThemeABC
    background_color: str = "#eff1f5"
    background_color_bright: str = "#ccd0da"

    surface_color: str = "#ccd0da"
    outline_color: str = "#8c8fa1"

    font_color: str = "#4c4f69"
    font_color_secondary: str = "#5c5f77"

    black: str = "#6c6f85"
    black_bright: str = "#bcc0cc"

    red: str = "#d20f39"
    red_bright: str = "#d20f39"

    green: str = "#40a02b"
    green_bright: str = "#40a02b"

    yellow: str = "#df8e1d"
    yellow_bright: str = "#df8e1d"

    blue: str = "#1e66f5"
    blue_bright: str = "#1e66f5"

    magenta: str = "#ea76cb"
    magenta_bright: str = "#ea76cb"

    cyan: str = "#179299"
    cyan_bright: str = "#179299"

    white: str = "#acb0be"
    white_bright: str = "#acb0be"

    # CatppuccinThemeABC
    rosewater: str = "#dc8a78"
    flamingo: str = "#dd7878"
    pink: str = "#ea76cb"
    mauve: str = "#8839ef"
    maroon: str = "#e64553"
    peach: str = "#fe640b"
    teal: str = "#179299"
    sky: str = "#04a5e5"
    sapphire: str = "#209fb5"
    lavender: str = "#7287fd"
    text: str = "#4c4f69"
    subtext1: str = "#5c5f77"
    subtext0: str = "#6c6f85"
    overlay2: str = "#7c7f93"
    overlay1: str = "#8c8fa1"
    overlay0: str = "#9ca0b0"
    surface2: str = "#acb0be"
    surface1: str = "#bcc0cc"
    surface0: str = "#ccd0da"
    base: str = "#eff1f5"
    mantle: str = "#e6e9ef"
    crust: str = "#dce0e8"
